==> tekton-model-triggers-v1alpha1-6.2.0-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerBindingSpecFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface TriggerBindingSpecFluent<A extends TriggerBindingSpecFluent<A>> extends Fluent<A>{
  public A addToParams(Integer index,Param item);
  public A setToParams(Integer index,Param item);
  public A addToParams(io.fabric8.tekton.triggers.v1alpha1.Param... items);
  public A addAllToParams(Collection<Param> items);
  public A removeFromParams(io.fabric8.tekton.triggers.v1alpha1.Param... items);
  public A removeAllFromParams(Collection<Param> items);
  public A removeMatchingFromParams(Predicate<ParamBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildParams instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Param> getParams();
  public List<Param> buildParams();
  public Param buildParam(Integer index);
  public Param buildFirstParam();
  public Param buildLastParam();
  public Param buildMatchingParam(Predicate<ParamBuilder> predicate);
  public Boolean hasMatchingParam(Predicate<ParamBuilder> predicate);
  public A withParams(List<Param> params);
  public A withParams(io.fabric8.tekton.triggers.v1alpha1.Param... params);
  public Boolean hasParams();
  public A addNewParam(String name,String value);
  public TriggerBindingSpecFluent.ParamsNested<A> addNewParam();
  public TriggerBindingSpecFluent.ParamsNested<A> addNewParamLike(Param item);
  public TriggerBindingSpecFluent.ParamsNested<A> setNewParamLike(Integer index,Param item);
  public TriggerBindingSpecFluent.ParamsNested<A> editParam(Integer index);
  public TriggerBindingSpecFluent.ParamsNested<A> editFirstParam();
  public TriggerBindingSpecFluent.ParamsNested<A> editLastParam();
  public TriggerBindingSpecFluent.ParamsNested<A> editMatchingParam(Predicate<ParamBuilder> predicate);
  public interface ParamsNested<N> extends Nested<N>,ParamFluent<TriggerBindingSpecFluent.ParamsNested<N>>{
    public N and();
    public N endParam();
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerBindingSpecFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface TriggerBindingSpecFluent<A extends TriggerBindingSpecFluent<A>> extends Fluent<A>{
  public A addToParams(int index,Param item);
  public A setToParams(int index,Param item);
  public A addToParams(io.fabric8.tekton.triggers.v1alpha1.Param... items);
  public A addAllToParams(Collection<Param> items);
  public A removeFromParams(io.fabric8.tekton.triggers.v1alpha1.Param... items);
  public A removeAllFromParams(Collection<Param> items);
  public A removeMatchingFromParams(Predicate<ParamBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildParams instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Param> getParams();
  public List<Param> buildParams();
  public Param buildParam(int index);
  public Param buildFirstParam();
  public Param buildLastParam();
  public Param buildMatchingParam(Predicate<ParamBuilder> predicate);
  public Boolean hasMatchingParam(Predicate<ParamBuilder> predicate);
  public A withParams(List<Param> params);
  public A withParams(io.fabric8.tekton.triggers.v1alpha1.Param... params);
  public Boolean hasParams();
  public A addNewParam(String name,String value);
  public TriggerBindingSpecFluent.ParamsNested<A> addNewParam();
  public TriggerBindingSpecFluent.ParamsNested<A> addNewParamLike(Param item);
  public TriggerBindingSpecFluent.ParamsNested<A> setNewParamLike(int index,Param item);
  public TriggerBindingSpecFluent.ParamsNested<A> editParam(int index);
  public TriggerBindingSpecFluent.ParamsNested<A> editFirstParam();
  public TriggerBindingSpecFluent.ParamsNested<A> editLastParam();
  public TriggerBindingSpecFluent.ParamsNested<A> editMatchingParam(Predicate<ParamBuilder> predicate);
  public interface ParamsNested<N> extends Nested<N>,ParamFluent<TriggerBindingSpecFluent.ParamsNested<N>>{
    public N and();
    public N endParam();
    
  }
  
}
